/*
  Generates 8x8bit 2398Hz "sine wave" on Arduino Uno PORTD pins.
  Formula for PicoScope MSO math channel DAC:

  LowPass((128*D7+64*D6+32*D5+16*D4+8*D3+4*D2+2*D1+1*D0)/256/0.996,15000)-0.5

  By HrHunt @ PicoTech forum
  E-mail: info@lab.fyi
  Thread: https://www.picotech.com/support/topic27831.html
*/  

const unsigned int iPoints = 256;
byte aiWave[iPoints];
unsigned int i;

void setup()
{
  pinMode(0, OUTPUT);
  pinMode(1, OUTPUT);
  pinMode(2, OUTPUT);
  pinMode(3, OUTPUT);
  pinMode(4, OUTPUT);
  pinMode(5, OUTPUT);
  pinMode(6, OUTPUT);
  pinMode(7, OUTPUT);

  float fPhaseStep = 2 * PI / iPoints;
  float fPhase = -PI;
  float fY;

  for (i = 0; i < iPoints; i++)
  {
    fY = sin(fPhase);
    fY = (fY + 0.9999) * (iPoints / 2);
    aiWave[i] = (byte) fY;
    fPhase += fPhaseStep;
  }

  Serial.begin(9600);
  Serial.end();
  PORTD = 0x00;
}

void loop()
{
  noInterrupts();
  while (true)
    for (i = 0; i < iPoints; i++)
      PORTD = aiWave[i];
}
